# Karbon
Karbon tracks background mouse events and turns them into artistic values!

## Setup
```sh
pip install karbon
```

## Running
```sh
python3 -m karbon
```

### After few hours later...
<div align="center">
  <img src="https://raw.githubusercontent.com/furkanonder/karbon/master/assets/examples/example.jpg" width=900px />
</div>
